Class: NetworkStorageApi::NfsPermissions

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_network_storage_api/models/nfs_permissions.rb

Overview

NFS specific permissions on a volume.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NfsPermissions

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkStorageApi::NfsPermissions` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkStorageApi::NfsPermissions`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'read_write')
    if (value = attributes[:'read_write']).is_a?(Array)
      self.read_write = value
    end
  end

  if attributes.key?(:'read_only')
    if (value = attributes[:'read_only']).is_a?(Array)
      self.read_only = value
    end
  end

  if attributes.key?(:'root_squash')
    if (value = attributes[:'root_squash']).is_a?(Array)
      self.root_squash = value
    end
  end

  if attributes.key?(:'no_squash')
    if (value = attributes[:'no_squash']).is_a?(Array)
      self.no_squash = value
    end
  end

  if attributes.key?(:'all_squash')
    if (value = attributes[:'all_squash']).is_a?(Array)
      self.all_squash = value
    end
  end
end

Instance Attribute Details

#all_squashObject

All squash permission.



32
33
34
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 32

def all_squash
  @all_squash
end

#no_squashObject

No squash permission.



29
30
31
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 29

def no_squash
  @no_squash
end

#read_onlyObject

Read only access.



23
24
25
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 23

def read_only
  @read_only
end

#read_writeObject

Read/Write access.



20
21
22
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 20

def read_write
  @read_write
end

#root_squashObject

Root squash permission.



26
27
28
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 26

def root_squash
  @root_squash
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 35

def self.attribute_map
  {
    :'read_write' => :'readWrite',
    :'read_only' => :'readOnly',
    :'root_squash' => :'rootSquash',
    :'no_squash' => :'noSquash',
    :'all_squash' => :'allSquash'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 161

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 56

def self.openapi_types
  {
    :'read_write' => :'Array<String>',
    :'read_only' => :'Array<String>',
    :'root_squash' => :'Array<String>',
    :'no_squash' => :'Array<String>',
    :'all_squash' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



136
137
138
139
140
141
142
143
144
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 136

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      read_write == o.read_write &&
      read_only == o.read_only &&
      root_squash == o.root_squash &&
      no_squash == o.no_squash &&
      all_squash == o.all_squash
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


148
149
150
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 148

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



154
155
156
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 154

def hash
  [read_write, read_only, root_squash, no_squash, all_squash].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 183

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
# File 'lib/pnap_network_storage_api/models/nfs_permissions.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end