Class: NetworkStorageApi::StorageNetworkVolumeCreate

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/pnap_network_storage_api/models/storage_network_volume_create.rb

Overview

Create Volume.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ StorageNetworkVolumeCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkStorageApi::StorageNetworkVolumeCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkStorageApi::StorageNetworkVolumeCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'path_suffix')
    self.path_suffix = attributes[:'path_suffix']
  end

  if attributes.key?(:'capacity_in_gb')
    self.capacity_in_gb = attributes[:'capacity_in_gb']
  else
    self.capacity_in_gb = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end
end

Instance Attribute Details

#capacity_in_gbObject

Capacity of Volume in GB. Currently only whole numbers and multiples of 1000GB are supported.



29
30
31
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 29

def capacity_in_gb
  @capacity_in_gb
end

#descriptionObject

Volume description.



23
24
25
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 23

def description
  @description
end

#nameObject

Volume friendly name.



20
21
22
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 20

def name
  @name
end

#path_suffixObject

Last part of volume’s path.



26
27
28
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 26

def path_suffix
  @path_suffix
end

#tagsObject

Tags to set to the resource. To create a new tag or list all the existing tags that you can use, refer to [Tags API](developers.phoenixnap.com/docs/tags/1/overview).



32
33
34
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 32

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 35

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'path_suffix' => :'pathSuffix',
    :'capacity_in_gb' => :'capacityInGb',
    :'tags' => :'tags'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 283

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 56

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'path_suffix' => :'String',
    :'capacity_in_gb' => :'Integer',
    :'tags' => :'Array<TagAssignmentRequest>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



258
259
260
261
262
263
264
265
266
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 258

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      path_suffix == o.path_suffix &&
      capacity_in_gb == o.capacity_in_gb &&
      tags == o.tags
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


270
271
272
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 270

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



276
277
278
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 276

def hash
  [name, description, path_suffix, capacity_in_gb, tags].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9(). -])+$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 250
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.')
  end

  if !@path_suffix.nil? && @path_suffix.to_s.length > 27
    invalid_properties.push('invalid value for "path_suffix", the character length must be smaller than or equal to 27.')
  end

  if !@path_suffix.nil? && @path_suffix.to_s.length < 0
    invalid_properties.push('invalid value for "path_suffix", the character length must be greater than or equal to 0.')
  end

  pattern = Regexp.new(/^(\/[\w-]+)+$|^$/)
  if !@path_suffix.nil? && @path_suffix !~ pattern
    invalid_properties.push("invalid value for \"path_suffix\", must conform to the pattern #{pattern}.")
  end

  if @capacity_in_gb.nil?
    invalid_properties.push('invalid value for "capacity_in_gb", capacity_in_gb cannot be nil.')
  end

  if @capacity_in_gb < 1000
    invalid_properties.push('invalid value for "capacity_in_gb", must be greater than or equal to 1000.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 305

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/pnap_network_storage_api/models/storage_network_volume_create.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 100
  return false if @name.to_s.length < 1
  return false if @name !~ Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9(). -])+$/)
  return false if !@description.nil? && @description.to_s.length > 250
  return false if !@path_suffix.nil? && @path_suffix.to_s.length > 27
  return false if !@path_suffix.nil? && @path_suffix.to_s.length < 0
  return false if !@path_suffix.nil? && @path_suffix !~ Regexp.new(/^(\/[\w-]+)+$|^$/)
  return false if @capacity_in_gb.nil?
  return false if @capacity_in_gb < 1000
  true
end