Class: NetworkStorageApi::VolumeUpdate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NetworkStorageApi::VolumeUpdate
- Defined in:
- lib/pnap_network_storage_api/models/volume_update.rb
Overview
Update storage network volume.
Instance Attribute Summary collapse
-
#capacity_in_gb ⇒ Object
Capacity of Volume in GB.
-
#description ⇒ Object
Volume description.
-
#name ⇒ Object
Volume friendly name.
-
#path_suffix ⇒ Object
Last part of volume’s path.
-
#permissions ⇒ Object
Returns the value of attribute permissions.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumeUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VolumeUpdate
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkStorageApi::VolumeUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkStorageApi::VolumeUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'capacity_in_gb') self.capacity_in_gb = attributes[:'capacity_in_gb'] end if attributes.key?(:'path_suffix') self.path_suffix = attributes[:'path_suffix'] end if attributes.key?(:'permissions') self. = attributes[:'permissions'] end end |
Instance Attribute Details
#capacity_in_gb ⇒ Object
Capacity of Volume in GB. Currently only whole numbers and multiples of 1000GB are supported.
26 27 28 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 26 def capacity_in_gb @capacity_in_gb end |
#description ⇒ Object
Volume description.
23 24 25 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 23 def description @description end |
#name ⇒ Object
Volume friendly name.
20 21 22 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 20 def name @name end |
#path_suffix ⇒ Object
Last part of volume’s path.
29 30 31 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 29 def path_suffix @path_suffix end |
#permissions ⇒ Object
Returns the value of attribute permissions.
31 32 33 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 31 def @permissions end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 34 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'capacity_in_gb' => :'capacityInGb', :'path_suffix' => :'pathSuffix', :'permissions' => :'permissions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 266 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 55 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'capacity_in_gb' => :'Integer', :'path_suffix' => :'String', :'permissions' => :'PermissionsUpdate' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
241 242 243 244 245 246 247 248 249 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 241 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && capacity_in_gb == o.capacity_in_gb && path_suffix == o.path_suffix && == o. end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 259 def hash [name, description, capacity_in_gb, path_suffix, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9(). -])+$/) if !@name.nil? && @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if !@description.nil? && @description.to_s.length > 250 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.') end if !@capacity_in_gb.nil? && @capacity_in_gb < 2000 invalid_properties.push('invalid value for "capacity_in_gb", must be greater than or equal to 2000.') end if !@path_suffix.nil? && @path_suffix.to_s.length > 27 invalid_properties.push('invalid value for "path_suffix", the character length must be smaller than or equal to 27.') end if !@path_suffix.nil? && @path_suffix.to_s.length < 0 invalid_properties.push('invalid value for "path_suffix", the character length must be greater than or equal to 0.') end pattern = Regexp.new(/^(\/[\w-]+)+$|^$/) if !@path_suffix.nil? && @path_suffix !~ pattern invalid_properties.push("invalid value for \"path_suffix\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/pnap_network_storage_api/models/volume_update.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 100 return false if !@name.nil? && @name.to_s.length < 1 return false if !@name.nil? && @name !~ Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9(). -])+$/) return false if !@description.nil? && @description.to_s.length > 250 return false if !@capacity_in_gb.nil? && @capacity_in_gb < 2000 return false if !@path_suffix.nil? && @path_suffix.to_s.length > 27 return false if !@path_suffix.nil? && @path_suffix.to_s.length < 0 return false if !@path_suffix.nil? && @path_suffix !~ Regexp.new(/^(\/[\w-]+)+$|^$/) true end |