Class: NetworkStorageApi::StorageNetwork
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NetworkStorageApi::StorageNetwork
- Defined in:
- lib/pnap_network_storage_api/models/storage_network.rb
Overview
Storage network.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#created_on ⇒ Object
Date and time when this storage network was created.
-
#delete_requested_on ⇒ Object
Date and time of the initial request for storage network deletion.
-
#description ⇒ Object
Storage network description.
-
#id ⇒ Object
Storage network ID.
-
#ips ⇒ Object
IP of the storage network.
-
#location ⇒ Object
Location of storage network.
-
#name ⇒ Object
Storage network friendly name.
-
#network_id ⇒ Object
Id of network the storage belongs to.
-
#status ⇒ Object
Returns the value of attribute status.
-
#volumes ⇒ Object
Volume for a storage network.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageNetwork
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ StorageNetwork
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkStorageApi::StorageNetwork` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkStorageApi::StorageNetwork`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'location') self.location = attributes[:'location'] end if attributes.key?(:'network_id') self.network_id = attributes[:'network_id'] end if attributes.key?(:'ips') if (value = attributes[:'ips']).is_a?(Array) self.ips = value end end if attributes.key?(:'created_on') self.created_on = attributes[:'created_on'] end if attributes.key?(:'delete_requested_on') self.delete_requested_on = attributes[:'delete_requested_on'] end if attributes.key?(:'volumes') if (value = attributes[:'volumes']).is_a?(Array) self.volumes = value end end end |
Instance Attribute Details
#created_on ⇒ Object
Date and time when this storage network was created.
40 41 42 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 40 def created_on @created_on end |
#delete_requested_on ⇒ Object
Date and time of the initial request for storage network deletion.
43 44 45 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 43 def delete_requested_on @delete_requested_on end |
#description ⇒ Object
Storage network description.
26 27 28 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 26 def description @description end |
#id ⇒ Object
Storage network ID.
20 21 22 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 20 def id @id end |
#ips ⇒ Object
IP of the storage network.
37 38 39 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 37 def ips @ips end |
#location ⇒ Object
Location of storage network. Currently this field should be set to ‘PHX` or `ASH`.
31 32 33 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 31 def location @location end |
#name ⇒ Object
Storage network friendly name.
23 24 25 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 23 def name @name end |
#network_id ⇒ Object
Id of network the storage belongs to.
34 35 36 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 34 def network_id @network_id end |
#status ⇒ Object
Returns the value of attribute status.
28 29 30 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 28 def status @status end |
#volumes ⇒ Object
Volume for a storage network.
46 47 48 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 46 def volumes @volumes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 71 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'status' => :'status', :'location' => :'location', :'network_id' => :'networkId', :'ips' => :'ips', :'created_on' => :'createdOn', :'delete_requested_on' => :'deleteRequestedOn', :'volumes' => :'volumes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 226 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 113 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 97 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'status' => :'Status', :'location' => :'String', :'network_id' => :'String', :'ips' => :'Array<String>', :'created_on' => :'Time', :'delete_requested_on' => :'Time', :'volumes' => :'Array<Volume>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 196 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && status == o.status && location == o.location && network_id == o.network_id && ips == o.ips && created_on == o.created_on && delete_requested_on == o.delete_requested_on && volumes == o.volumes end |
#eql?(o) ⇒ Boolean
213 214 215 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 213 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
219 220 221 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 219 def hash [id, name, description, status, location, network_id, ips, created_on, delete_requested_on, volumes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
181 182 183 184 185 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 181 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 248 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 |
# File 'lib/pnap_network_storage_api/models/storage_network.rb', line 189 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |