Class: NetworkStorageApi::StorageNetworkCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NetworkStorageApi::StorageNetworkCreate
- Defined in:
- lib/pnap_network_storage_api/models/storage_network_create.rb
Overview
Create Storage Network.
Instance Attribute Summary collapse
-
#client_vlan ⇒ Object
Custom Client VLAN that the Storage Network will be set to.
-
#description ⇒ Object
Storage network description.
-
#location ⇒ Object
Location of storage network.
-
#name ⇒ Object
Storage network friendly name.
-
#volumes ⇒ Object
Volume to be created alongside storage.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageNetworkCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ StorageNetworkCreate
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkStorageApi::StorageNetworkCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkStorageApi::StorageNetworkCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'location') self.location = attributes[:'location'] else self.location = nil end if attributes.key?(:'volumes') if (value = attributes[:'volumes']).is_a?(Array) self.volumes = value end else self.volumes = nil end if attributes.key?(:'client_vlan') self.client_vlan = attributes[:'client_vlan'] end end |
Instance Attribute Details
#client_vlan ⇒ Object
Custom Client VLAN that the Storage Network will be set to.
32 33 34 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 32 def client_vlan @client_vlan end |
#description ⇒ Object
Storage network description.
23 24 25 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 23 def description @description end |
#location ⇒ Object
Location of storage network. Currently this field should be set to ‘PHX` or `ASH`.
26 27 28 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 26 def location @location end |
#name ⇒ Object
Storage network friendly name.
20 21 22 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 20 def name @name end |
#volumes ⇒ Object
Volume to be created alongside storage. Currently only 1 volume is supported.
29 30 31 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 29 def volumes @volumes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 35 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'location' => :'location', :'volumes' => :'volumes', :'client_vlan' => :'clientVlan' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 298 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 56 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'location' => :'String', :'volumes' => :'Array<StorageNetworkVolumeCreate>', :'client_vlan' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
273 274 275 276 277 278 279 280 281 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 273 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && location == o.location && volumes == o.volumes && client_vlan == o.client_vlan end |
#eql?(o) ⇒ Boolean
285 286 287 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 285 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
291 292 293 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 291 def hash [name, description, location, volumes, client_vlan].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9(). -])+$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if !@description.nil? && @description.to_s.length > 250 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.') end if @location.nil? invalid_properties.push('invalid value for "location", location cannot be nil.') end if @volumes.nil? invalid_properties.push('invalid value for "volumes", volumes cannot be nil.') end if @volumes.length > 1 invalid_properties.push('invalid value for "volumes", number of items must be less than or equal to 1.') end if @volumes.length < 1 invalid_properties.push('invalid value for "volumes", number of items must be greater than or equal to 1.') end if !@client_vlan.nil? && @client_vlan > 4094 invalid_properties.push('invalid value for "client_vlan", must be smaller than or equal to 4094.') end if !@client_vlan.nil? && @client_vlan < 2 invalid_properties.push('invalid value for "client_vlan", must be greater than or equal to 2.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 320 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/pnap_network_storage_api/models/storage_network_create.rb', line 172 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length > 100 return false if @name.to_s.length < 1 return false if @name !~ Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9(). -])+$/) return false if !@description.nil? && @description.to_s.length > 250 return false if @location.nil? return false if @volumes.nil? return false if @volumes.length > 1 return false if @volumes.length < 1 return false if !@client_vlan.nil? && @client_vlan > 4094 return false if !@client_vlan.nil? && @client_vlan < 2 true end |