Class: NetworkStorageApi::Volume
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NetworkStorageApi::Volume
- Defined in:
- lib/pnap_network_storage_api/models/volume.rb
Overview
Volume for a storage network.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#capacity_in_gb ⇒ Object
Maximum capacity in GB.
-
#created_on ⇒ Object
Returns the value of attribute created_on.
-
#delete_requested_on ⇒ Object
Date and time of the initial request for volume deletion.
-
#description ⇒ Object
Volume description.
-
#id ⇒ Object
Volume ID.
-
#name ⇒ Object
Volume friendly name.
-
#path ⇒ Object
Volume’s full path.
-
#path_suffix ⇒ Object
Last part of volume’s path.
-
#permissions ⇒ Object
Returns the value of attribute permissions.
-
#protocol ⇒ Object
File system protocol.
-
#status ⇒ Object
Returns the value of attribute status.
-
#tags ⇒ Object
The tags assigned if any.
-
#used_capacity_in_gb ⇒ Object
Used capacity in GB, updated periodically.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Volume
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Volume
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 133 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkStorageApi::Volume` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkStorageApi::Volume`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'path') self.path = attributes[:'path'] end if attributes.key?(:'path_suffix') self.path_suffix = attributes[:'path_suffix'] end if attributes.key?(:'capacity_in_gb') self.capacity_in_gb = attributes[:'capacity_in_gb'] end if attributes.key?(:'used_capacity_in_gb') self.used_capacity_in_gb = attributes[:'used_capacity_in_gb'] end if attributes.key?(:'protocol') self.protocol = attributes[:'protocol'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'created_on') self.created_on = attributes[:'created_on'] end if attributes.key?(:'delete_requested_on') self.delete_requested_on = attributes[:'delete_requested_on'] end if attributes.key?(:'permissions') self. = attributes[:'permissions'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#capacity_in_gb ⇒ Object
Maximum capacity in GB.
35 36 37 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 35 def capacity_in_gb @capacity_in_gb end |
#created_on ⇒ Object
Returns the value of attribute created_on.
45 46 47 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 45 def created_on @created_on end |
#delete_requested_on ⇒ Object
Date and time of the initial request for volume deletion.
48 49 50 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 48 def delete_requested_on @delete_requested_on end |
#description ⇒ Object
Volume description.
26 27 28 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 26 def description @description end |
#id ⇒ Object
Volume ID.
20 21 22 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 20 def id @id end |
#name ⇒ Object
Volume friendly name.
23 24 25 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 23 def name @name end |
#path ⇒ Object
Volume’s full path. It is in form of ‘/volumeId/pathSuffix`’.
29 30 31 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 29 def path @path end |
#path_suffix ⇒ Object
Last part of volume’s path.
32 33 34 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 32 def path_suffix @path_suffix end |
#permissions ⇒ Object
Returns the value of attribute permissions.
50 51 52 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 50 def @permissions end |
#protocol ⇒ Object
File system protocol. Currently this field should be set to ‘NFS`.
41 42 43 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 41 def protocol @protocol end |
#status ⇒ Object
Returns the value of attribute status.
43 44 45 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 43 def status @status end |
#tags ⇒ Object
The tags assigned if any.
53 54 55 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 53 def @tags end |
#used_capacity_in_gb ⇒ Object
Used capacity in GB, updated periodically.
38 39 40 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 38 def used_capacity_in_gb @used_capacity_in_gb end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
97 98 99 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 97 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
102 103 104 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 102 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 78 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'path' => :'path', :'path_suffix' => :'pathSuffix', :'capacity_in_gb' => :'capacityInGb', :'used_capacity_in_gb' => :'usedCapacityInGb', :'protocol' => :'protocol', :'status' => :'status', :'created_on' => :'createdOn', :'delete_requested_on' => :'deleteRequestedOn', :'permissions' => :'permissions', :'tags' => :'tags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 252 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
126 127 128 129 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 126 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 107 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'path' => :'String', :'path_suffix' => :'String', :'capacity_in_gb' => :'Integer', :'used_capacity_in_gb' => :'Integer', :'protocol' => :'String', :'status' => :'Status', :'created_on' => :'Time', :'delete_requested_on' => :'Time', :'permissions' => :'Permissions', :'tags' => :'Array<TagAssignment>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 219 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && path == o.path && path_suffix == o.path_suffix && capacity_in_gb == o.capacity_in_gb && used_capacity_in_gb == o.used_capacity_in_gb && protocol == o.protocol && status == o.status && created_on == o.created_on && delete_requested_on == o.delete_requested_on && == o. && == o. end |
#eql?(o) ⇒ Boolean
239 240 241 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 239 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
245 246 247 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 245 def hash [id, name, description, path, path_suffix, capacity_in_gb, used_capacity_in_gb, protocol, status, created_on, delete_requested_on, , ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
204 205 206 207 208 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 204 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 274 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
212 213 214 215 |
# File 'lib/pnap_network_storage_api/models/volume.rb', line 212 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |