Class: NetworkStorageApi::VolumeCreate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NetworkStorageApi::VolumeCreate
- Defined in:
- lib/pnap_network_storage_api/models/volume_create.rb
Overview
Create Volume.
Instance Attribute Summary collapse
-
#capacity_in_gb ⇒ Object
Capacity of Volume in GB.
-
#description ⇒ Object
Volume description.
-
#name ⇒ Object
Volume friendly name.
-
#path_suffix ⇒ Object
Last part of volume’s path.
-
#permissions ⇒ Object
Returns the value of attribute permissions.
-
#tags ⇒ Object
Tags to set to the resource.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumeCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VolumeCreate
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NetworkStorageApi::VolumeCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NetworkStorageApi::VolumeCreate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'path_suffix') self.path_suffix = attributes[:'path_suffix'] end if attributes.key?(:'capacity_in_gb') self.capacity_in_gb = attributes[:'capacity_in_gb'] else self.capacity_in_gb = nil end if attributes.key?(:'permissions') self. = attributes[:'permissions'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#capacity_in_gb ⇒ Object
Capacity of Volume in GB. Currently only whole numbers and multiples of 1000GB are supported.
29 30 31 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 29 def capacity_in_gb @capacity_in_gb end |
#description ⇒ Object
Volume description.
23 24 25 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 23 def description @description end |
#name ⇒ Object
Volume friendly name.
20 21 22 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 20 def name @name end |
#path_suffix ⇒ Object
Last part of volume’s path.
26 27 28 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 26 def path_suffix @path_suffix end |
#permissions ⇒ Object
Returns the value of attribute permissions.
31 32 33 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 31 def @permissions end |
#tags ⇒ Object
Tags to set to the resource. To create a new tag or list all the existing tags that you can use, refer to [Tags API](developers.phoenixnap.com/docs/tags/1/overview).
34 35 36 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 34 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 37 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'path_suffix' => :'pathSuffix', :'capacity_in_gb' => :'capacityInGb', :'permissions' => :'permissions', :'tags' => :'tags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 292 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 59 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'path_suffix' => :'String', :'capacity_in_gb' => :'Integer', :'permissions' => :'PermissionsCreate', :'tags' => :'Array<TagAssignmentRequest>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
266 267 268 269 270 271 272 273 274 275 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 266 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && path_suffix == o.path_suffix && capacity_in_gb == o.capacity_in_gb && == o. && == o. end |
#eql?(o) ⇒ Boolean
279 280 281 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 279 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 285 def hash [name, description, path_suffix, capacity_in_gb, , ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9(). -])+$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if !@description.nil? && @description.to_s.length > 250 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 250.') end if !@path_suffix.nil? && @path_suffix.to_s.length > 27 invalid_properties.push('invalid value for "path_suffix", the character length must be smaller than or equal to 27.') end if !@path_suffix.nil? && @path_suffix.to_s.length < 0 invalid_properties.push('invalid value for "path_suffix", the character length must be greater than or equal to 0.') end pattern = Regexp.new(/^(\/[\w-]+)+$|^$/) if !@path_suffix.nil? && @path_suffix !~ pattern invalid_properties.push("invalid value for \"path_suffix\", must conform to the pattern #{pattern}.") end if @capacity_in_gb.nil? invalid_properties.push('invalid value for "capacity_in_gb", capacity_in_gb cannot be nil.') end if @capacity_in_gb < 1000 invalid_properties.push('invalid value for "capacity_in_gb", must be greater than or equal to 1000.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 314 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/pnap_network_storage_api/models/volume_create.rb', line 175 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length > 100 return false if @name.to_s.length < 1 return false if @name !~ Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9(). -])+$/) return false if !@description.nil? && @description.to_s.length > 250 return false if !@path_suffix.nil? && @path_suffix.to_s.length > 27 return false if !@path_suffix.nil? && @path_suffix.to_s.length < 0 return false if !@path_suffix.nil? && @path_suffix !~ Regexp.new(/^(\/[\w-]+)+$|^$/) return false if @capacity_in_gb.nil? return false if @capacity_in_gb < 1000 true end |